@@ -47,7 +47,7 @@ class Parser():
                     (self.arguments[1] == "State")):         # time interval
                 #print("* State - Ready     Blue    Red     Black   Black   None_             1830   1631   2230      76      ")    
                 print ("         |ModeSystem     |ModeFlight             |ModeControlFlight           |ModeMovement      |Headless       |ControlSpeed     |SensorOrientation    |Battery  |")
-                self.request(DataType.State, int(self.arguments[2]), float(self.arguments[3]))
+                self.request(DeviceType.Drone, DataType.State, int(self.arguments[2]), float(self.arguments[3]))
                 return
 
             # >python -m e_drone request Motion 10 0.2
@@ -57,7 +57,7 @@ class Parser():
                 #print("* Motion      -38      64     -32     457     -40    -400      16       0   20500")    
                 print ("         |Accel                  |Gyro                   |Angle                  |")
                 print ("         |      X|      Y|      Z|   Roll|  Pitch|    Yaw|   Roll|  Pitch|    Yaw|")
-                self.request(DataType.Motion, int(self.arguments[2]), float(self.arguments[3]))
+                self.request(DeviceType.Drone, DataType.Motion, int(self.arguments[2]), float(self.arguments[3]))
                 return
 
             # >python -m e_drone request CardRaw 10 0.2
@@ -67,7 +67,7 @@ class Parser():
                 #print("* CardRaw   335  503  766  692  309  395 100  39  96  40   9  17 303  61  39 344  77  15   Magenta         Red")
                 print ("          |Front Raw     |Rear Raw      |Front RGB  |Rear RGB   |Front HSVL      |Rear HSVL       |Front Color  |Rear Color   |")
                 print ("          |   R    G    B|   R    G    B|  R   G   B|  R   G   B|  H   S   V   L|  H   S   V   L|             |             |")
-                self.request(DataType.CardRaw, int(self.arguments[2]), float(self.arguments[3]))
+                self.request(DeviceType.Drone, DataType.CardRaw, int(self.arguments[2]), float(self.arguments[3]))
                 return
 
             # >python -m e_drone request CardRange 10 0.2
@@ -78,29 +78,77 @@ class Parser():
                 print ("               |Front                              |Rear                               |")
                 print ("               |Red        |Green      |Blue       |Red        |Green      |Blue       |")
                 print ("               |  Min|  Max|  Min|  Max|  Min|  Max|  Min|  Max|  Min|  Max|  Min|  Max|")
-                self.request(DataType.CardRange, int(self.arguments[2]), float(self.arguments[3]))
+                self.request(DeviceType.Drone, DataType.CardRange, int(self.arguments[2]), float(self.arguments[3]))
+                return
+
+            # 이륙
+            #                   0       1
+            # python -m e_drone command Takeoff
+            elif    ((self.count == 2) and 
+                    (self.arguments[0] == "command") and
+                    (self.arguments[1] == "Takeoff")):
+                print (Fore.YELLOW + "command Takeoff" + Style.RESET_ALL)
+                self.command(CommandType.FlightEvent, FlightEvent.TakeOff.value)
+                return
+
+            # 착륙
+            #                   0       1
+            # python -m e_drone command Landing
+            elif    ((self.count == 2) and 
+                    (self.arguments[0] == "command") and
+                    (self.arguments[1] == "Landing")):
+                print (Fore.YELLOW + "command Landing" + Style.RESET_ALL)
+                self.command(CommandType.FlightEvent, FlightEvent.Landing.value)
+                return
+
+            # 정지
+            #                   0       1
+            # python -m e_drone command Stop
+            elif    ((self.count == 2) and 
+                    (self.arguments[0] == "command") and
+                    (self.arguments[1] == "Stop")):
+                print (Fore.YELLOW + "command Stop" + Style.RESET_ALL)
+                self.command(CommandType.FlightEvent, FlightEvent.Stop.value)
                 return
 
             # 조종
-            #                           1        2      3       4     5          6
-            # python -m e_drone_nightly control [roll] [pitch] [yaw] [throttle] [time(ms)]
+            #                   0        1      2       3     4          5
+            # python -m e_drone control [roll] [pitch] [yaw] [throttle] [time(ms)]
             # 지정한 시간이 종료되면 입력값을 모두 0으로 변경하고 멈춤
-            # >python -m e_drone_nightly control 40 0 3
+            # >python -m e_drone control 40 0 3
             elif    ((self.count == 6) and 
                     (self.arguments[0] == "control")):
                 print (Fore.YELLOW + "control" + Style.RESET_ALL)
                 self.control(int(self.arguments[1]), int(self.arguments[2]), int(self.arguments[3]), int(self.arguments[4]), int(self.arguments[5]))
                 return
 
-            # 이동
-            #                           1         2   3   4   5          6         7
-            # python -m e_drone_nightly position [x] [y] [z] [velocity] [heading] [rotational velocity]
+            # 이동(전체)
+            #                   0         1   2   3   4          5         6
+            # python -m e_drone position [x] [y] [z] [velocity] [heading] [rotational velocity]
             elif    ((self.count == 7) and 
                     (self.arguments[0] == "position")):
                 print (Fore.YELLOW + "position" + Style.RESET_ALL)
                 self.controlPosition(float(self.arguments[1]), float(self.arguments[2]), float(self.arguments[3]), float(self.arguments[4]), float(self.arguments[5]), float(self.arguments[6]))
                 return
 
+            # 이동(위치)
+            #                   0         1   2   3   4
+            # python -m e_drone position [x] [y] [z] [velocity]
+            elif    ((self.count == 5) and 
+                    (self.arguments[0] == "position")):
+                print (Fore.YELLOW + "position" + Style.RESET_ALL)
+                self.controlPosition(float(self.arguments[1]), float(self.arguments[2]), float(self.arguments[3]), float(self.arguments[4]), 0, 0)
+                return
+
+            # 이동(헤딩)
+            #                   0        1         2
+            # python -m e_drone heading [heading] [rotational velocity]
+            elif    ((self.count == 3) and 
+                    (self.arguments[0] == "heading")):
+                print (Fore.YELLOW + "heading" + Style.RESET_ALL)
+                self.controlPosition(0, 0, 0, 0, float(self.arguments[1]), float(self.arguments[2]))
+                return
+
             # 버저
             #                   1       2    3
             # python -m e_drone buzzer [hz] [time(ms)]
@@ -170,6 +218,18 @@ class Parser():
             sleep(interval)
 
 
+    def command(self, commandType, option = 0):
+
+        drone = Drone(True, True, True, True, True)
+        #drone = Drone()
+        if drone.open() == False:
+            print(Fore.RED + "* Error : Unable to open serial port." + Style.RESET_ALL)
+            sys.exit(1)
+
+        # 데이터 요청
+        drone.sendCommand(commandType, option);
+
+
     def control(self, roll, pitch, yaw, throttle, timeMs):
 
         drone = Drone(True, True, True, True, True)
@@ -363,18 +423,36 @@ class Parser():
         print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "request " + Fore.WHITE + "[" + Fore.YELLOW + "data type" + Fore.WHITE + "] [" + Fore.GREEN + "number of times" + Fore.WHITE + "] [" + Fore.YELLOW + "time interval(sec)" + Fore.WHITE + "]" + Style.RESET_ALL)
         print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "request " + Fore.YELLOW + "State " + Fore.GREEN + "10 " + Fore.YELLOW + "0.2" + Style.RESET_ALL)
         print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "request " + Fore.YELLOW + "Motion " + Fore.GREEN + "10 " + Fore.YELLOW + "0.2" + Style.RESET_ALL)
-        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "request " + Fore.YELLOW + "RawCard " + Fore.GREEN + "10 " + Fore.YELLOW + "0.2" + Style.RESET_ALL)
-        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "request " + Fore.YELLOW + "RawCardRange " + Fore.GREEN + "10 " + Fore.YELLOW + "0.2" + Style.RESET_ALL)
+        ## 카드 코딩과 관련된 내용이 최신 버전인지 알 수 없는 관계로 일단 보류(2021.1.4)
+        ##print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "request " + Fore.YELLOW + "RawCard " + Fore.GREEN + "10 " + Fore.YELLOW + "0.2" + Style.RESET_ALL)
+        ##print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "request " + Fore.YELLOW + "RawCardRange " + Fore.GREEN + "10 " + Fore.YELLOW + "0.2" + Style.RESET_ALL)
+
+        print("")
+        print(Fore.CYAN + "  - Command" + Style.RESET_ALL)
+        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "command " + Fore.WHITE + "[" + Fore.YELLOW + "Command" + Fore.WHITE + "]" + Style.RESET_ALL)
+        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "command " + Fore.YELLOW + "Takeoff" + Style.RESET_ALL)
+        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "command " + Fore.YELLOW + "Landing" + Style.RESET_ALL)
+        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "command " + Fore.YELLOW + "Stop" + Style.RESET_ALL)
+
+        print("")
+        print(Fore.CYAN + "  - Control" + Style.RESET_ALL)
+        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "control " + Fore.WHITE + "[" + Fore.YELLOW + "roll" + Fore.WHITE + "] [" + Fore.GREEN + "pitch" + Fore.WHITE + "] [" + Fore.YELLOW + "yaw" + Fore.WHITE + "] [" + Fore.GREEN + "throttle" + Fore.WHITE + "] [" + Fore.YELLOW + "time(ms)" + Fore.WHITE + "]" + Style.RESET_ALL)
+        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "control " + Fore.YELLOW + "0 " + Fore.GREEN + "30 " + Fore.YELLOW + "0 " + Fore.GREEN + "0 " + Fore.YELLOW + "5000 " + Style.RESET_ALL)
+
+        print("")
+        print(Fore.CYAN + "  - Control - Position, Heading" + Style.RESET_ALL)
+        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "position " + Fore.WHITE + "[" + Fore.RED + "x(meter)" + Fore.WHITE + "] [" + Fore.GREEN + "y(meter)" + Fore.WHITE + "] [" + Fore.BLUE + "z(meter)" + Fore.WHITE + "] [" + Fore.YELLOW + "speed(m/sec)" + Fore.WHITE + "] [" + Fore.MAGENTA + "heading(degree)" + Fore.WHITE + "] [" + Fore.YELLOW + "rotational velocity(deg/sec)" + Fore.WHITE + "]" + Style.RESET_ALL)
+        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "position " + Fore.RED + "5 " + Fore.GREEN + "0 " + Fore.BLUE + "0"  + Fore.YELLOW + "2 " + Fore.MAGENTA + "90 " + Fore.YELLOW + "45 "+ Style.RESET_ALL)
 
         print("")
         print(Fore.CYAN + "  - Control - Position" + Style.RESET_ALL)
-        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "position " + Fore.WHITE + "[" + Fore.YELLOW + "x(meter)" + Fore.WHITE + "] [" + Fore.GREEN + "y(meter)" + Fore.WHITE + "] [" + Fore.YELLOW + "speed(m/sec)" + Fore.WHITE + "]" + Style.RESET_ALL)
-        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "position " + Fore.YELLOW + "0.1 " + Fore.GREEN + "0.1 " + Fore.YELLOW + "0.2" + Style.RESET_ALL)
+        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "position " + Fore.WHITE + "[" + Fore.RED + "x(meter)" + Fore.WHITE + "] [" + Fore.GREEN + "y(meter)" + Fore.WHITE + "] [" + Fore.BLUE + "z(meter)" + Fore.WHITE + "] [" + Fore.YELLOW + "speed(m/sec)" + Fore.WHITE + "] [" + Fore.MAGENTA + "heading(degree)" + Fore.WHITE + "] [" + Fore.YELLOW + "rotational velocity(deg/sec)" + Fore.WHITE + "]" + Style.RESET_ALL)
+        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "position " + Fore.RED + "5 " + Fore.GREEN + "0 " + Fore.BLUE + "0"  + Fore.YELLOW + "2 " + Style.RESET_ALL)
 
         print("")
         print(Fore.CYAN + "  - Control - Heading" + Style.RESET_ALL)
         print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "heading " + Fore.WHITE + "[" + Fore.YELLOW + "heading(degree)" + Fore.WHITE + "] [" + Fore.GREEN + "rotational velocity(deg/sec)" + Fore.WHITE + "]" + Style.RESET_ALL)
-        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "heading " + Fore.YELLOW + "30 " + Fore.GREEN + "10" + Style.RESET_ALL)
+        print(Fore.GREEN + "   > " + Fore.WHITE + "python -m e_drone " + Fore.CYAN + "heading " + Fore.YELLOW + "90 " + Fore.GREEN + "45" + Style.RESET_ALL)
 
         print("")
         print(Fore.CYAN + "  - Buzzer" + Style.RESET_ALL)
